==> haskell-ghc-lib-parser-ex-9.4.0.0-99-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-lib-parser-ex
version:              9.4.0.0
visibility:           public
id:                   ghc-lib-parser-ex-9.4.0.0-GvFRk4KDoKD9WoD6eXLh8X
key:                  ghc-lib-parser-ex-9.4.0.0-GvFRk4KDoKD9WoD6eXLh8X
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  d954c6f7a8cb5e97cfc7bc3f9a7bef80
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.4.0.0-GvFRk4KDoKD9WoD6eXLh8X
include-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0/include

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-9.4.8
    ghc-boot-9.4.8 ghc-boot-th-9.4.8
    uniplate-1.6.13-6AZxRZigT9K4tvBk80lMWK

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-lib-parser-ex-9.6.0.2-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-lib-parser-ex
version:              9.6.0.2
visibility:           public
id:                   ghc-lib-parser-ex-9.6.0.2-1ItHaVihRUCCxYoN9mTsaz
key:                  ghc-lib-parser-ex-9.6.0.2-1ItHaVihRUCCxYoN9mTsaz
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  a007c2bf0f0a06e1d1523f9376a0aa40
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/ghc-lib-parser-ex-9.6.0.2

library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/ghc-lib-parser-ex-9.6.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/ghc-lib-parser-ex-9.6.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.6.0.2-1ItHaVihRUCCxYoN9mTsaz
include-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/ghc-lib-parser-ex-9.6.0.2/include

depends:
    base-4.18.3.0 bytestring-0.11.5.4 containers-0.6.7
    ghc-9.6.7.20250817 ghc-boot-9.6.7.20250817
    ghc-boot-th-9.6.7.20250817 uniplate-1.6.13-1hVfdUwJg9OIVMxxBjGlEn

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
